@@ -7,8 +7,8 @@ from bodo_platform_utils.utils_types import CloudProvider
 
 def _get_ssm_parameter(parameter_name):
     ssm_client = boto3.client("ssm", REGION)
-    parameters = ssm_client.get_parameter(Name=parameter_name, WithDecryption=True)
-    data = json.loads(parameters["Parameter"].get("Value"))
+    parameters = ssm_client.get_parameters(Names=[parameter_name], WithDecryption=True)
+    data = json.loads(parameters["Parameters"][0].get("Value"))
     return data
 
 
@@ -30,7 +30,13 @@ def _get_ssm_parameter_parallel(parameter_name):
 
 
 # Users have to use the below helper functions to get the secrets from SSM.
+
 def snowflake_credentials(_parallel=True):
+    """
+    :param _parallel(Optional) - Defaults to True
+
+    :return: snowflake credentials as JSON
+    """
     if CLOUD_PROVIDER == CloudProvider.AWS:
         parameter_name = (
             f"/bodo/workspaces/{WORKSPACE_UUID}/secrets/snowflake_credentials"
